@@ -50,13 +50,11 @@ COLORINPUT_HEX_FORMAT_UPPER = 'upper'
 
 # Custom typing
 ColorInputColorType = Literal[COLORINPUT_TYPE_RGB, COLORINPUT_TYPE_HEX]
-ColorInputHexFormatType = Literal[COLORINPUT_HEX_FORMAT_LOWER,
-                                  COLORINPUT_HEX_FORMAT_UPPER,
-                                  COLORINPUT_HEX_FORMAT_NONE]
+ColorInputHexFormatType = Literal[COLORINPUT_HEX_FORMAT_LOWER, COLORINPUT_HEX_FORMAT_UPPER, COLORINPUT_HEX_FORMAT_NONE]
 
 
 # noinspection PyMissingOrEmptyDocstring
-class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
+class ColorInput(TextInput):
     """
     Color input widget.
 
@@ -88,7 +86,7 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
     :param input_underline_vmargin: Vertical margin of underline in px
     :param cursor_color: Color of cursor
     :param onchange: Function when changing the values of the color text
-    :param onreturn: Function when pressing return on the color text input
+    :param onreturn: Function when pressing return (apply) on the color text input
     :param onselect: Function when selecting the widget
     :param prev_margin: Horizontal margin between the previsualization and the input text in px
     :param prev_width_factor: Width of the previsualization box in terms of the height of the widget
@@ -363,8 +361,7 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
         self._rect.width, self._rect.height = self._surface.get_size()
         if not self._dynamic_width or \
                 (self._dynamic_width and self._previsualization_surface is not None):
-            self._rect.width += self._prev_width_factor * self._rect.height \
-                                + self._prev_margin
+            self._rect.width += self._prev_width_factor * self._rect.height + self._prev_margin
 
         # Render the previsualization box
         r, g, b = self.get_value()
@@ -385,8 +382,7 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
                 self._last_g = g
                 self._last_b = b
                 if self._dynamic_width:
-                    self._rect.width += self._prev_width_factor * self._rect.height \
-                                        + self._prev_margin
+                    self._rect.width += self._prev_width_factor * self._rect.height + self._prev_margin
 
         return render_text
 
@@ -674,7 +670,7 @@ class ColorInputManager(AbstractWidgetManager, ABC):
         :param input_separator: Divisor between RGB channels, not valid in HEX format
         :param input_underline: Underline character
         :param onchange: Callback executed when changing the values of the color text
-        :param onreturn: Callback executed when pressing return on the color input
+        :param onreturn: Callback executed when pressing return (apply) on the color input
         :param onselect: Callback executed when selecting the widget
         :param kwargs: Optional keyword arguments
         :return: Widget object
